#!/usr/bin/env python

import socket, sys, time, traceback
import libasyncns

if __name__ == '__main__':
	
	if '-h' in sys.argv[1:]:
		print('{0} [-e] [-h]'.format(sys.argv[0]))
		print('  -e: add invalid addresses to trigger errors')
		print('  -h: display this help')
		sys.exit(0)
	
	ips = [
	       '203.178.141.194',                    # www.kame.net (IPv4)
	       '2001:200:0:8002:203:47ff:fea5:3085', # www.kame.net (IPv6)
	       '209.85.135.104',                     # www.ipv6.org (IPv4)
	       '2001:6b0:1:ea:202:a5ff:fecd:13a6',   # www.ipv6.org (IPv6)
	       '127.0.0.1',                          # localhost (IPv4)
	       '::ffff:127.0.0.1',                   # localhost (IPv4 mapped IPv6)
	       '::1',                                # localhost (IPv6)
	      ]
	
	if '-e' in sys.argv[1:]:
		ips.append('2001:db8::1') # doesn't resolve (IPv6 example)
		ips.append('::zzz')       # invalid
	
	def is_ipv4(ip):
		try:
			socket.inet_pton(socket.AF_INET, ip)
			return True
		except:
			return False
	
	print('socket.getnameinfo(...):')
	t = time.time()
	for ip in ips:
		try:
			if is_ipv4(ip):
				print('  {0}: {1}'.format(ip, socket.getnameinfo((ip, 0), 0)))
			else:
				print('  {0}: {1}'.format(ip, socket.getnameinfo((ip, 0, 0, 0), 0)))
		except:
			print('Exception for "{0}":'.format(ip))
			traceback.print_exc()
	print('{0} seconds'.format(time.time() - t))
	print('')
	
	print('asyncns.getnameinfo(...):')
	t = time.time()
	asyncns = libasyncns.Asyncns()
	for ip in ips:
		if is_ipv4(ip):
			q = asyncns.getnameinfo((ip, 0), 0)
		else:
			q = asyncns.getnameinfo((ip, 0, 0, 0), 0)
		q.userdata = ip
	
	while asyncns.get_nqueries() > 0:
		asyncns.wait(True)
		q = True
		while q:
			try: q = asyncns.get_next()
			except: q = None
			if q and q.is_done():
				try:
					print('  {0}: {1}'.format(q.userdata, q.get_done()))
				except:
					print('Exception for "{0}":'.format(q.userdata))
					traceback.print_exc()
	print('{0} seconds'.format(time.time() - t))
	print('')
	
