#!/usr/bin/env python

import socket, sys, time, traceback
import libasyncns

if __name__ == '__main__':
	
	if '-h' in sys.argv[1:]:
		print('{0} [-e] [-h]'.format(sys.argv[0]))
		print('  -e: add invalid addresses to trigger errors')
		print('  -h: display this help')
		sys.exit(0)
	
	dnames = [
	        ('_xmpp-client._tcp.gmail.com',
	          libasyncns.ns_c_in, libasyncns.ns_t_srv),
	        ('_xmpp-client._tcp.jabber.org',
	          libasyncns.ns_c_in, libasyncns.ns_t_srv),
	        ('good-AAAA.test.dnssec-tools.org',
	          libasyncns.ns_c_in, libasyncns.ns_t_aaaa),
	       ]
	
	if '-e' in sys.argv[1:]:
		# can't be resolved (reserved)
		dnames.append(('a.com', libasyncns.ns_c_in, libasyncns.ns_t_a))
		# can't be resolved (invalid TLD)
		dnames.append(('www.invalid', libasyncns.ns_c_in, libasyncns.ns_t_srv))
		# can't be resolved (invalid)
		dnames.append(('\x10', libasyncns.ns_c_in, libasyncns.ns_t_a))
		# must be queried as ns_t_a, not ns_t_aaaa
		dnames.append(('good-A.test.dnssec-tools.org',
		              libasyncns.ns_c_in, libasyncns.ns_t_aaaa))
	
	print('asyncns.res_query(...):')
	t = time.time()
	asyncns = libasyncns.Asyncns()
	for dname in dnames:
		q = asyncns.res_query(*dname)
		q.userdata = dname
	
	while asyncns.get_nqueries() > 0:
		asyncns.wait(True)
		q = True
		while q:
			try: q = asyncns.get_next()
			except: q = None
			if q and q.is_done():
				try:
					for r in q.get_done():
						print('  {0}: {1}'.format(q.userdata, list(r.values())))
				except:
					print('Exception for "{0}":'.format(str(q.userdata)))
					traceback.print_exc()
	print('{0} seconds'.format(time.time() - t))
	print('')
	
